@@ -34,6 +34,6 @@ class CompuScale(NamedTuple):
     description: Optional[str] = None
     lower_limit: Optional[Limit] = None
     upper_limit: Optional[Limit] = None
-    compu_inverse_value: Optional[Union[float, str]] = None
+    compu_inverse_value: Optional[Union[float, str, bytearray]] = None
     compu_const: Optional[Union[float, str]] = None
     compu_rational_coeffs: Optional[CompuRationalCoeffs] = None
